@@ -1,4 +1,4 @@
-/* Copyright 2013--2018 The Tor Project
+/* Copyright 2013--2020 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.metrics.onionoo.server;
@@ -45,7 +45,7 @@ public class ResourceServletTest {
 
   private static long TEST_TIME = DateTimeHelper.parse("2013-04-24 12:22:22");
 
-  private class TestingHttpServletRequestWrapper
+  private static class TestingHttpServletRequestWrapper
       extends HttpServletRequestWrapper {
     private String requestUri;
     private String queryString;
@@ -78,7 +78,7 @@ public class ResourceServletTest {
     }
   }
 
-  private class TestingHttpServletResponseWrapper extends
+  private static class TestingHttpServletResponseWrapper extends
       HttpServletResponseWrapper {
 
     private TestingHttpServletResponseWrapper() {
@@ -1134,7 +1134,7 @@ public class ResourceServletTest {
         null);
   }
 
-  @Test(timeout = 200)
+  @Test(timeout = 800)
   public void testCountryDeDe() {
     this.assertSummaryDocument(
         "/summary?country=de&country=de", 1, new String[] { "TorkaZ" }, 0,
@@ -1358,7 +1358,7 @@ public class ResourceServletTest {
   @Test(timeout = 100)
   public void testFirstSeenDaysMaxInt() {
     this.assertSummaryDocument(
-        "/summary?last_seen_days=" + String.valueOf(Integer.MAX_VALUE), 0,
+        "/summary?last_seen_days=" + Integer.MAX_VALUE, 0,
         null, 0, null);
   }
 
@@ -1366,7 +1366,7 @@ public class ResourceServletTest {
   public void testFirstSeenDaysMaxIntPlusOne() {
     this.assertErrorStatusCode(
         "/summary?first_seen_days="
-        + String.valueOf(((long) Integer.MAX_VALUE) + 1L), 400);
+        + (((long) Integer.MAX_VALUE) + 1L), 400);
   }
 
   @Test(timeout = 100)
